import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean)

setup(name='elisa-plugin-coherence',
      version='0.1', 
      description='UPnP related services',
      long_description='UPnP related services',
      license='UNKNOWN', 
      author='Elisa Developers',
      author_email='elisa@lists.fluendo.com',
      keywords='',
      install_requires=['coherence>=0.5.7', 'elisa-plugin-httpd', 'elisa-plugin-twisted'],
      namespace_packages=['elisa', 'elisa.plugins'],
      packages=packages,
      package_dir=package_dir,
      package_data={'': ['*.png', '*.mo', '*.po']},
      cmdclass=cmdclass,
      entry_points="""
      [elisa.core.components.resource_provider]
      CoherenceResource = coherence.coherence_resource:CoherenceResource
      UpnpResource = elisa.plugins.coherence.upnp_resource:UpnpResource

      [elisa.core.components.service_provider]
      CoherenceService = elisa.plugins.coherence.coherence_service:CoherenceService
      """)
